<?xml version="1.0"?>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:saxon="http://icl.com/saxon"
    extension-element-prefixes="saxon"
    xmlns:date="http://exslt.org/dates-and-times">

<xsl:param name="language">en</xsl:param>
<xsl:param name="warn-localization">0</xsl:param>

<xsl:output method="html" encoding="utf-8"/>

<!-- we don't want any output from our tool -->
<xsl:template match="text()|@*">
</xsl:template>

<!-- utility template to output non localized text -->
<xsl:template match="processing-instruction()|comment()|@*" mode="unlocalized">
</xsl:template>

<xsl:template match="xref" mode="unlocalized" priority="2">
    <xsl:variable name="id" select="@id"/>
    <xsl:choose>
        <xsl:when test="/help/section/topic[@id=$id]">
            <xsl:variable name="pos">
                <xsl:for-each select="/help/section/topic[@id=$id]">
                    <xsl:value-of select="count(preceding-sibling::topic)+1"/>
                </xsl:for-each>
            </xsl:variable>
            <xsl:variable name="tpos">
                <xsl:for-each select="/help/section/topic[@id=$id]">
                    <xsl:value-of select="count(parent::*/preceding-sibling::section)+1"/>
                </xsl:for-each>
            </xsl:variable>
            <a href="page{$tpos}-{$pos}.html">
                <xsl:apply-templates mode="unlocalized"/>
            </a>
        </xsl:when>
        <xsl:when test="/help/section[@id=$id]">
            <xsl:variable name="pos">
                <xsl:for-each select="/help/section[@id=$id]">
                    <xsl:value-of select="count(preceding-sibling::section)+1"/>
                </xsl:for-each>
            </xsl:variable>
            <a href="topic{$pos}.html">
                <xsl:apply-templates mode="unlocalized"/>
            </a>
        </xsl:when>
        <xsl:otherwise>
            <xsl:message>Missing link id=<xsl:value-of select="$id"/>.</xsl:message>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="choosemenuitem" mode="unlocalized" priority="2">
    <xsl:variable name="id" select="@id"/>
    <xsl:variable name="menu">
        <xsl:apply-templates select="/help/menus/menu[items/item/@id=$id]/title" mode="localized"/>
    </xsl:variable>
    <xsl:variable name="menuitem">
        <xsl:apply-templates select="/help/menus/menu/items/item[@id=$id]" mode="localized"/>
    </xsl:variable>
    <xsl:if test="string-length($menuitem)=0">
        <xsl:message>Missing menu item id=<xsl:value-of select="$id"/>.</xsl:message>
    </xsl:if>
    <xsl:apply-templates select="/help/miscellaneous/choosemenuitemtext" mode="localized"/>
    <xsl:text> </xsl:text>
    <b><xsl:copy-of select="$menu"/></b>
    <xsl:text> &gt; </xsl:text>
    <b><xsl:copy-of select="$menuitem"/></b>
    <xsl:if test="not(contains(substring($menuitem,string-length($menuitem)-1,1),'.'))">.</xsl:if>
</xsl:template>

<xsl:template match="menuitem" mode="unlocalized" priority="2">
    <xsl:variable name="id" select="@id"/>
    <xsl:variable name="menu">
        <xsl:apply-templates select="/help/menus/menu[items/item/@id=$id]/title" mode="localized"/>
    </xsl:variable>
    <xsl:variable name="menuitem">
        <xsl:apply-templates select="/help/menus/menu/items/item[@id=$id]" mode="localized"/>
    </xsl:variable>
    <xsl:if test="string-length($menuitem)=0">
        <xsl:message>Missing menu item id=<xsl:value-of select="$id"/>.</xsl:message>
    </xsl:if>
    <b><xsl:copy-of select="$menu"/></b>
    <xsl:text> &gt; </xsl:text>
    <b><xsl:copy-of select="$menuitem"/></b>
</xsl:template>

<xsl:template match="keyitem" mode="unlocalized" priority="2">
    <xsl:variable name="id" select="@id"/>
    <xsl:variable name="keyitem">
        <xsl:apply-templates select="/help/keys/key[@id=$id]" mode="localized"/>
    </xsl:variable>
    <xsl:if test="string-length($keyitem)=0">
        <xsl:message>Missing key item id=<xsl:value-of select="$id"/>.</xsl:message>
    </xsl:if>
    <b><xsl:copy-of select="$keyitem"/></b>
</xsl:template>

<xsl:template match="toolbaritem|key|button|proper|column|application" mode="unlocalized" priority="2">
    <b><xsl:apply-templates mode="unlocalized"/></b>
</xsl:template>

<xsl:template match="*|/" mode="unlocalized" priority="1">
    <xsl:apply-templates mode="unlocalized"/>
</xsl:template>

<xsl:template match="text()" mode="unlocalized" priority="1">
    <xsl:value-of select="."/>
</xsl:template>

<!-- select the language to output -->
<xsl:template match="*" mode="localized">
    <xsl:variable name="text">
        <xsl:if test="child::text[@lang=$language]">
            <xsl:apply-templates select="child::text[@lang=$language]" mode="unlocalized"/>
        </xsl:if>
        <xsl:if test="not(child::text[@lang=$language]) and child::text[@lang='en']">
            <xsl:if test="$warn-localization!=0"><xsl:message>English only: <xsl:apply-templates select="en" mode="unlocalized"/></xsl:message></xsl:if>
            <xsl:apply-templates select="en" mode="unlocalized"/>
        </xsl:if>
        <xsl:if test="not(child::text[@lang=$language]) and not(child::text[@lang='en']) and not(child::*)">
            <xsl:if test="$warn-localization!=0"><xsl:message>Not localized: <xsl:value-of select="name()"/><xsl:apply-templates select="." mode="unlocalized"/></xsl:message></xsl:if>
            <xsl:apply-templates select="." mode="unlocalized"/>
        </xsl:if>
    </xsl:variable>
    <xsl:copy-of select="$text"/>
</xsl:template>

<xsl:template name="output-explanatory-text">
    <xsl:param name="field"/>
    <xsl:if test="count($field) &gt; 0">
        <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="7">
            <TR>
                <TD>
                    <P>
                        <font SIZE="2" FACE="Lucida Grande,Geneva,Arial">
                            <xsl:for-each select="$field">
                                <xsl:apply-templates select="." mode="localized"/>
                                    <xsl:if test="not(position()=last())">
                                    <br/><br/>
                                </xsl:if>
                            </xsl:for-each>
                        </font>
                    </P>
                </TD>
            </TR>
        </TABLE>
    </xsl:if>
</xsl:template>

<xsl:template name="output-navigator">
    <table width="100%" border="0" cellspacing="0" cellpadding="0">
        <tr align="left" valign="top" height="40">
            <td align="left" valign="top" width="7" height="40">&#160;</td>
            <td align="left" valign="top" width="40" height="40">
                <img height="32" width="32">
                    <xsl:attribute name="src">
                        <xsl:value-of select="/help/miscellaneous/image32"/>
                    </xsl:attribute>
                    <xsl:attribute name="alt">
                        <xsl:apply-templates select="/help/miscellaneous/applicationname" mode="localized"/>
                    </xsl:attribute>
                </img>
            </td>
            <td align="left" valign="top" height="40">
                <font size="2" face="Lucida Grande,Geneva,Arial">
                    <a HREF="topic1.html">
                        <xsl:apply-templates select="/help/miscellaneous/helptext" mode="localized"/>
                    </a>
                </font>
            </td>
        </tr>
    </table>
</xsl:template>

<xsl:template name="output-meta-copyright">
    <meta name="copyright" content="Copyright 2003-2005 LQ Graphics, Inc. All Rights Reserved."/>
    <meta name="datagen">
        <xsl:attribute name="content">
            <xsl:value-of select="date:date-time()"/>
        </xsl:attribute>
    </meta>
    <meta name="generator" content="Saxon 6.5.2"/>
</xsl:template>

<xsl:template name="output-toc-pane">
    <TABLE WIDTH="130" BORDER="0" CELLSPACING="0" CELLPADDING="0">
    <TR>
        <TD WIDTH="120">
            <img height="128" width="128">
                <xsl:attribute name="src">
                    <xsl:value-of select="/help/miscellaneous/image128"/>
                </xsl:attribute>
                <xsl:attribute name="alt">
                    <xsl:apply-templates select="/help/miscellaneous/applicationname" mode="localized"/>
                </xsl:attribute>
            </img>
        </TD>
        <TD></TD>
    </TR>
    <TR VALIGN="top">
        <TD WIDTH="120"><font SIZE="2" COLOR="#666666" FACE="Lucida Grande,Helvetica,Arial">
            <xsl:apply-templates select="/help/miscellaneous/blurb" mode="localized"/>
        </font></TD>
        <TD></TD>
    </TR>
    <TR VALIGN="top" HEIGHT="15">
        <TD WIDTH="120" HEIGHT="15"></TD>
        <TD HEIGHT="15"></TD>
    </TR>
    <TR VALIGN="top">
        <TD WIDTH="120"><font SIZE="4" FACE="Lucida Grande"><xsl:apply-templates select="/help/miscellaneous/title" mode="localized"/></font></TD>
        <TD></TD>
    </TR>
    <TR VALIGN="top" HEIGHT="10">
        <TD WIDTH="120" HEIGHT="10">&#160;</TD>
        <TD HEIGHT="10"></TD>
    </TR>
    </TABLE>

    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="0">
        <xsl:for-each select="/help/section/title">
            <TR VALIGN="top">
                <TD WIDTH="125">
                    <A TARGET="_top" href="topic{position()}.html">
                        <font FACE="Lucida Grande,Helvetica,Arial" SIZE="2">
                            <xsl:apply-templates select="." mode="localized"/>
                        </font>
                    </A>
                </TD>
            </TR>
        <xsl:if test="position() != last()">
            <TR VALIGN="top" HEIGHT="10">
                <TD WIDTH="125" HEIGHT="10"></TD>
            </TR>
        </xsl:if>
        </xsl:for-each>
    </TABLE>

</xsl:template>

<!-- template to output the content frame and topic list frame -->
<xsl:template name="output-table-for-contents">
    <xsl:param name="content"/>
    <table width="100%" border="0" cellspacing="0" cellpadding="8">
        <tr align="left" valign="top" height="20">
            <td align="left" valign="top" width="170">
                <!-- blurb for searching -->
                <xsl:call-template name="output-toc-pane"/>
            </td>
            <td align="left" valign="middle">
                <TABLE BORDER="0" FRAME="" CELLSPACING="0" CELLPADDING="0">
                    <TR VALIGN="middle">
                        <TD WIDTH="1"></TD>
                        <TD>
                            <TABLE BORDER="0" CELLSPACING="0" CELLPADDING="0">
                                <TR VALIGN="top">
                                    <TD>
                                        <font SIZE="2" FACE="Lucida Grande,Helvetica,Arial">
                                            <xsl:copy-of select="$content"/>
                                        </font>
                                    </TD>
                                </TR>
                            </TABLE>
                        </TD>
                    </TR>
                </TABLE>
            </td>
        </tr>
    </table>
</xsl:template>

<xsl:template name="output-topics-toc">
    <xsl:for-each select="section">
        <xsl:variable name="tpos" select="position()"/>
        <saxon:output href="pages/topic{$tpos}.html">
            <html xml:lang="en">
                <head>
                    <title><xsl:apply-templates select="title" mode="localized"/></title>
                    <xsl:call-template name="output-meta-copyright"/>
                    <xsl:if test="$tpos=1">
                        <meta name="AppleTitle">
                            <xsl:attribute name="content">
                                <xsl:apply-templates select="/help/miscellaneous/applicationname" mode="localized"/>
                                <xsl:text> Help</xsl:text>
                            </xsl:attribute>
                        </meta>
                        <meta name="AppleIcon">
                            <xsl:attribute name="content">
                                <xsl:apply-templates select="/help/miscellaneous/applicationname" mode="localized"/>
                                <xsl:text> Help/</xsl:text><xsl:value-of select="/help/miscellaneous/image16"/>
                            </xsl:attribute>
                        </meta>
                    </xsl:if>
                </head>
        
                <body bgcolor="#ffffff" marginheight="0" marginwidth="0" topmargin="0">
        
                    <xsl:call-template name="output-table-for-contents">
                        <xsl:with-param name="content">
                        <xsl:if test="child::content">
                            <xsl:apply-templates select="content" mode="topic"/>
                        </xsl:if>
                        <xsl:if test="child::topic">
                            <TR VALIGN="top" HEIGHT="10">
                                <TD WIDTH="100%" HEIGHT="10"></TD>
                            </TR>
                            <TR VALIGN="top">
                                <TD WIDTH="100%"><font SIZE="2" FACE="Lucida Grande,Helvetica,Arial">
                                    <b><xsl:apply-templates select="title" mode="localized"/></b>
                                </font></TD>
                            </TR>
                            <xsl:for-each select="topic">
                                <TR VALIGN="top" HEIGHT="10">
                                    <TD WIDTH="100%" HEIGHT="10"></TD>
                                </TR>
                                <TR VALIGN="top">
                                    <TD WIDTH="100%">
                                        <A HREF="page{$tpos}-{position()}.html">
                                            <font SIZE="2" FACE="Lucida Grande,Helvetica,Arial">
                                                <xsl:apply-templates select="title" mode="localized"/>
                                            </font>
                                        </A>
                                    </TD>
                                </TR>
                            </xsl:for-each>
                        </xsl:if>
                        </xsl:with-param>
                    </xsl:call-template>
                </body>
            </html>
        </saxon:output>
    </xsl:for-each>
</xsl:template>

<xsl:template match="help">
    <xsl:apply-templates/>
    <xsl:call-template name="output-topics-toc"/>
</xsl:template>

<xsl:template match="help/section">
    <xsl:apply-templates select="topic"/>
</xsl:template>

<xsl:template match="title" mode="topic">
    <!-- the title of the section -->
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="7">
        <TR>
            <TD>
                <P>
                    <font SIZE="4" FACE="Lucida Grande,Helvetica,Arial">
                        <B><xsl:apply-templates select="." mode="localized"/></B>
                    </font>
                </P>
            </TD>
        </TR>
    </TABLE>
</xsl:template>

<xsl:template match="link" mode="topic">
    <xsl:variable name="href" select="@href"/>
    <!-- the title of the section -->
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="7">
        <TR>
            <TD>
                <P>
                    <font SIZE="2" FACE="Lucida Grande,Geneva,Arial">
                        <a href="{$href}"><xsl:apply-templates select="." mode="localized"/></a>
                    </font>
                </P>
            </TD>
        </TR>
    </TABLE>
</xsl:template>

<xsl:template match="steps" mode="topic">
    <xsl:variable name="scolor">
        <xsl:if test="not(@style) or @style=''">
            <xsl:value-of select="/help/miscellaneous/colors/stepsbackground"/>
        </xsl:if>
        <xsl:if test="@style='tutorial'">
            <xsl:text>#FFFFFF</xsl:text>
        </xsl:if>
    </xsl:variable>
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="7" BGCOLOR="{$scolor}">
        <TR VALIGN="top" BGCOLOR="{$scolor}">
            <TD BGCOLOR="{$scolor}" WIDTH="98%">
                <xsl:if test="title">
                    <font FACE="Lucida Grande,Helvetica,Arial" SIZE="2">
                        <B><xsl:apply-templates select="title" mode="localized"/></B>
                        <BR/><BR/>
                    </font>
                </xsl:if>
                <font SIZE="2" FACE="Lucida Grande,Geneva,Arial">
                    <xsl:for-each select="step|graphics">
                        <TABLE BORDER="0" CELLSPACING="0" CELLPADDING="3">
                        <TR VALIGN="top">
                            <TD WIDTH="16">
                            <xsl:choose>
                                <xsl:when test="self::step">
                                    <font SIZE="2" FACE="Lucida Grande,Helvetica,Arial">
                                    <xsl:choose>
                                        <xsl:when test="count(../step) > 1">
                                            <B><xsl:value-of select="count(preceding-sibling::step)+1"/></B>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <B>&#149;</B>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    </font>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:variable name="name" select="@name" />
                                    <xsl:variable name="filename" select="document('images.xml')/images/image[@name=$name]/@file"/>
                                    <xsl:choose>
                                        <xsl:when test="$filename!=''">
                                            <img src="graphics/{$filename}"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:message>Missing image filename=<xsl:value-of select="$name"/>.</xsl:message>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                            </TD>
                            <TD>
                                <xsl:if test="self::step">
                                    <font SIZE="2" FACE="Lucida Grande,Geneva,Arial">
                                        <xsl:apply-templates select="." mode="localized"/>
                                    </font>
                                </xsl:if>
                            </TD>
                        </TR>
                        </TABLE>
                    </xsl:for-each>
                </font>
            </TD>
        </TR>
    </TABLE>
    <xsl:if test="following-sibling::steps">
        <br/>
    </xsl:if>
</xsl:template>

<xsl:template match="graphics" mode="topic">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="7">
        <TR>
            <TD>
                <P>
                    <xsl:variable name="name" select="@name" />
                    <xsl:variable name="filename" select="document('images.xml')/images/image[@name=$name]/@file"/>
                    <xsl:choose>
                        <xsl:when test="$filename!=''">
                            <img src="graphics/{$filename}"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:message>Missing image filename=<xsl:value-of select="$name"/>.</xsl:message>
                        </xsl:otherwise>
                    </xsl:choose>
                </P>
            </TD>
        </TR>
    </TABLE>
</xsl:template>

<xsl:template match="explanation" mode="topic">
    <xsl:call-template name="output-explanatory-text">
        <xsl:with-param name="field" select="."/>
    </xsl:call-template>
</xsl:template>

<xsl:template name="topic-navigator-table-columns">
    <xsl:variable name="tpos" select="count(parent::*/preceding-sibling::section)+1"/>
    <xsl:if test="position() != 1">
        <td>
            <p><font SIZE="2" FACE="Lucida Grande,Geneva,Arial"><a href="page{$tpos}-{position()-1}.html">Previous Topic</a></font></p>
        </td>
    </xsl:if>
    <xsl:if test="position() != last()">
        <td>
            <p><font SIZE="2" FACE="Lucida Grande,Geneva,Arial"><a href="page{$tpos}-{position()+1}.html">Next Topic</a></font></p>
        </td>
    </xsl:if>
</xsl:template>

<xsl:template match="topic">
    <xsl:variable name="tpos" select="count(parent::*/preceding-sibling::section)+1"/>
    <saxon:output href="pages/page{$tpos}-{position()}.html">
    <html xml:lang="en">
        <head>
            <title><xsl:apply-templates select="title" mode="localized"/></title>
            <xsl:call-template name="output-meta-copyright"/>
        </head>

        <body bgcolor="#ffffff" marginheight="0" marginwidth="0" topmargin="0">
            <div align="left">
                
                <!-- top of the page which gives a link back to the main index -->
                <xsl:call-template name="output-navigator"/>
                
                <TABLE BORDER="0" CELLSPACING="0" CELLPADDING="7">
                    <TR>
                        <TD>
                            <P>
                                <font SIZE="2" FACE="Lucida Grande,Geneva,Arial">
                                    <a href="topic{$tpos}.html">
                                        <xsl:apply-templates select="parent::*/title" mode="localized"/>
                                    </a>
                                </font>
                            </P>
                        </TD>
                        <xsl:call-template name="topic-navigator-table-columns"/>
                    </TR>
                </TABLE>

                <hr/>

                <xsl:apply-templates select="." mode="topic"/>

                <hr/>
                
                <table BORDER="0" CELLSPACING="0" CELLPADDING="7">
                    <tr>
                        <xsl:call-template name="topic-navigator-table-columns"/>
                    </tr>
                </table>

            </div>
        </body>
    </html>
    </saxon:output>
</xsl:template>

</xsl:stylesheet>
